Groups
Groups
UpdatePermissions
Update permissions
Request
POST /api/manage/v1/Groups/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | ||
| body |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Permissions are updated |
|
| 400 | id or VM is not valid |
|
| 402 | Subscription is outdated |
|
| 403 | You have no permissions to work with groups |
|
| 404 | Group or subscription is not found |
GetPermissions
Gets group permissions by identifier
Request
GET /api/manage/v1/Groups/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of group |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully retured |
|
| 400 | The request is wrong |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Group with this identifier or subscription is not found |
GetGroup
Gets group by identifier
Request
GET /api/manage/v1/Groups/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of group |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully retured |
|
| 400 | The request is wrong |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Group with this identifier or subscription is not found |
DeleteGroup
Delete group by identifier
Request
DELETE /api/manage/v1/Groups/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of group |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Succesfully delete |
|
| 400 | The request is wrong |
|
| 402 | Subscripiton is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Group with this identifier or subscription is not found |
GetGroupList
Returns a list of current user's groups
This method will return following data about groups :
Id, Name, Created time (UTC), Edited time (UTC), creator id,
editor id, subscription id
Request
GET /api/manage/v1/Groups[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| skip | integer | 0 | How many groups need to skip |
| take | integer | 10 | How many groups need to take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully retured |
|
| 400 | The request is wrong |
|
| 401 | User is unauthorized |
CreateGroup
Create a new user group
Request
POST /api/manage/v1/Groups
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| body | Model for creating |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully created |
|
| 400 | The request is wrong |
|
| 402 | subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Information from view model is not found |
RenameGroup
Rename group by identifier
Request
PUT /api/manage/v1/Groups/{id}/rename
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of group |
|
| *body | Model for renaming |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully renamed |
|
| 400 | The request is wrong |
|
| 402 | subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Group with this identifier or subscription is not found |
GetMyPermissions
Get current user's permissions to group
Request
GET /api/manage/v1/Groups/{id}/mypermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of group |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully retured |
|
| 400 | The request is wrong |
|
| 404 | Group with this identifier or subscription is not found |
|
| 500 | Server Error |
Definitions
UpdateGroupPermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
GroupPermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
GroupPermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
GroupCreate
GroupDelete
GroupExecute
GroupGet
GroupUpdate
GroupAdministrate
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
GroupPermissionsVM
| Name | Type | Notes |
|---|---|---|
| permissions |
|
|
| $t | string |
GroupVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| name | string | |
| subscriptionId | string | |
| $t | string |
GroupsVM
| Name | Type | Notes |
|---|---|---|
| groups |
|
|
| count | integer (int64) | |
| skip | integer (int32) | |
| take | integer (int32) | |
| $t | string |
CreateGroupVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| subscriptionId | string | |
| $t | string |
RenameGroupVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| $t | string |